#! /usr/bin/env python
# ezfc-tool.py
# Copyright (C) 2011 Akira TAGOH

# Authors:
#   Akira TAGOH  <akira@tagoh.org>

# This library is free software: you can redistribute it and/or
# modify it under the terms of the GNU Lesser General Public
# License as published by the Free Software Foundation, either
# version 3 of the License, or (at your option) any later version.

# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.

# You should have received a copy of the GNU General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from gi.repository import Easyfc
import gi
import os.path
import sys
import getopt

def __cmd_add_cb(argv):
    opts, args = getopt.getopt(argv, 'h', ['help', 'no-load'])
    opts.append(('', None)) # just to ensure entering the loop
    loadconf = True
    for o, a in opts:
        if o in ('-h', '--help') or len(args) != 3:
            print 'Usage: %s add [options] <lang> <alias> <family>' % os.path.basename(sys.argv[0])
            print 'Options:'
            print '  -h or --help    Show this message'
            print '  --no-load       Do not load the configuration file'
            sys.exit()
        elif o == '--no-load':
            loadconf = False

    config = Easyfc.Config()
    if loadconf:
        try:
            config.load()
        except gi._glib.GError, e:
            if e.domain == 'ezfc-error-quark' and e.code == 7:
                pass
            else:
                raise
    alias = Easyfc.Alias.new(args[1])
    alias.set_font(args[2])
    config.add_alias(args[0], alias)
    config.save()
    print '%s has been added as the alias of %s for %s' % (args[2], args[1], args[0])

def __cmd_remove_cb(argv):
    opts, args = getopt.getopt(argv, 'h', ['help'])
    opts.append(('', None)) # just to ensure entering the loop
    for o, a in opts:
        if o in ('-h', '--help') or len(args) != 2:
            print 'Usage: %s add [options] <lang> <alias>' % os.path.basename(sys.argv[0])
            print 'Options:'
            print '  -h or --help    Show this message'
            sys.exit()

    config = Easyfc.Config()
    try:
        config.load()
    except gi._glib.GError, e:
        if e.domain == 'ezfc-error-quark' and e.code == 7:
            print 'E: no configuration file available'
            sys.exit()
        else:
            raise

    config.remove_alias(args[0], args[1])
    config.save()
    print '%s has been removed from %s' % (args[1], args[0])

def __cmd_show_cb(argv):
    opts, args = getopt.getopt(argv, 'h', ['help'])
    opts.append(('', None)) # just to ensure entering the loop
    for o, a in opts:
        if o in ('-h', '--help') or len(args) > 2:
            print 'Usage: %s add [options] [lang] [alias]' % os.path.basename(sys.argv[0])
            print 'Options:'
            print '  -h or --help    Show this message'
            sys.exit()

    config = Easyfc.Config()
    try:
        config.load()
    except gi._glib.GError, e:
        if e.domain == 'ezfc-error-quark' and e.code == 7:
            print 'E: no configuration file available'
            sys.exit()
        else:
            raise

    if len(args) == 0:
        config.dump()
    elif len(args) == 1:
        l = config.get_aliases(args[0])
        if len(l) == 0:
            print 'E: no aliases defined for %s' % args[0]
        else:
            for a in l:
                print '%s: %s' % (a.get_name(), a.get_font())
    else:
        l = config.get_aliases(args[0])
        if len(l) == 0:
            print 'E: no aliases defined for %s' % args[0]
        else:
            if args[1] == 'sans':
                alias = 'sans-serif'
            else:
                alias = args[1]
            for a in l:
                if a.get_name() == alias:
                    print a.get_font()
                    sys.exit()
            print 'E: no such alias for %s: %s' % (args[0], args[1])

def __cmd_fonts_cb(argv):
    opts, args = getopt.getopt(argv, 'a:l:h', ['alias=', 'lang=', 'help'])
    opts.append(('', None)) # just to ensure entering the loop
    alias = None
    lang = None
    for o, a in opts:
        if o in ('-h', '--help'):
            print 'Usage: %s add [options]' % os.path.basename(sys.argv[0])
            print 'Options:'
            print '  -h or --help         Show this message'
            print '  -a or --alias=ALIAS  Set ALIAS as the alias font name for query'
            print '  -l or --lang=LANG    Set LANG as the language for query'
            sys.exit()
        elif o in ('-a', '--alias'):
            alias = a
        elif o in ('-l', '--lang'):
            lang = a

    Easyfc.init()
    fonts = Easyfc.get_fonts_list(lang, alias)
    print '%s (lang=%s):' % (alias, lang)
    for f in fonts:
        print '  %s' % f

    Easyfc.finalize()

def __cmd_help_cb(argv):
    print 'Usage: %s <command> ...' % os.path.basename(sys.argv[0])
    print 'Commands:'
    print '  %s' % ', '.join(commands.keys())
    sys.exit()

commands = {
    "add":__cmd_add_cb,
    "remove":__cmd_remove_cb,
    "show":__cmd_show_cb,
    "fonts":__cmd_fonts_cb,
    "help":__cmd_help_cb,
}

if len(sys.argv) == 1:
    __cmd_help_cb(sys.argv[1:])
if sys.argv[1] in commands.keys():
    commands[sys.argv[1]](sys.argv[2:])
else:
    __cmd_help_cb(sys.argv[2:])
